@@ -252,11 +252,11 @@ class AgentClient:
             nodes = self.all_nodes
         return self._query(requests.get, 'percept-data', nodes=nodes)
 
-    def get_cognition_data(self, nodes: List = None) -> Union[dict, Tuple[dict, str]]:
+    def get_cognition_data(self, unique_id: str = None, nodes: List = None) -> Union[dict, Tuple[dict, str]]:
         """Return cognition data."""
         if nodes is None:
             nodes = self.query_nodes
-        return self._query(requests.get, 'cognition-data', nodes=nodes)
+        return self._query(requests.get, 'cognition-data', nodes=nodes, unique_id=unique_id)
 
     @_ensure_connected
     def change_genes(self, gene_data: Dict, nodes: List = None) -> Union[dict, Any]:
