@@ -9,7 +9,6 @@ from ipywidgets import FloatProgress
 from pymongo import MongoClient
 
 from ia.gaius.data_ops import Data
-from ia.gaius.data_language import CLEAR_ALL_MEMORY
 from ia.gaius.tests import classification, utility
 
 
@@ -179,7 +178,7 @@ class BackTest:
                                           'number_of_things_done': self.number_of_things_done,
                                           'current_test_count': self.current_test_count}, upsert=True)
         if self.fresh_start_memory:
-            self.bottle.observe(CLEAR_ALL_MEMORY)
+            self.bottle.clear_all_memory()
         return 'ready'
 
     def _train(self, sequence):
