@@ -1,5 +1,5 @@
 from ia.gaius.data_language import CLEAR_WM, LEARN
-from ia.gaius.prediction_models import prediction_ensemble_model_utility, hive_model_utility
+from ia.gaius.prediction_models import make_modeled_emotives, hive_model_emotives
 
 
 class Tester:
@@ -36,11 +36,11 @@ class Tester:
         # HERE IS WHERE WE MODEL OUR PREDICTIONS #######
         for answer in answers:
             for node, ensemble in answer.items():
-                predicted_value = prediction_ensemble_model_utility(ensemble)
+                predicted_value = make_modeled_emotives(ensemble)
                 hive_prediction.append(predicted_value)  # Add to hive model's list for later
                 record['node_predictions'][node] = predicted_value
 
-        hive_prediction = hive_model_utility(hive_prediction)
+        hive_prediction = hive_model_emotives(hive_prediction)
         record['node_predictions']['hive'] = hive_prediction
         if hive_prediction == historical_expecting:
             predicton_error = False
